.. _data-format:

Data formats
=============


.. _field-data:

Fields
++++++++

.. toctree::
   :maxdepth: 1

   grib
   netcdf


.. _non-field-data:

Non-fields (points/observations)
++++++++++++++++++++++++++++++++++

.. toctree::
   :maxdepth: 1
   :glob:

   csv
   bufr
   odb
